@@ -1,11 +1,11 @@
 //! Global constants, such as compiler version used, algorithms, compression and filters supported and others
 
-pub const COMPILATION_DATE: &str = "Feb 09 2021";
-pub const COMPILATION_TIME: &str = "14:39:14";
-pub const VERSION: &str = "0.4.10";
+pub const COMPILATION_DATE: &str = "Sep 01 2021";
+pub const COMPILATION_TIME: &str = "16:47:29";
+pub const VERSION: &str = "0.4.11";
 pub const ALGORITHMS: [&str; 10] = ["alpha","multiplicative","source_over","destination_over","mask_top","first_top","first_bottom","disjoint_over","disjoint_under","disjoint_debug"];
 pub const COMPILER: &str = "rustc";
-pub const COMPILER_VERSION: &str = "1.44.1";
+pub const COMPILER_VERSION: &str = "1.51.0";
 pub const LIBPNG_VERSION: &str = "image-0.23";
 pub const FEATURES: [&str; 2] = ["cpu","python"];
 pub const PLATFORM_CPU_BITS: &str = "64";
